=========================================================
networking-ovn - OpenStack Neutron integration with OVN
=========================================================

OVN provides virtual networking for Open vSwitch and is a component of the Open
vSwitch project.  This project provides integration between OpenStack Neutron
and OVN.

* Free software: Apache license
* Source: http://git.openstack.org/cgit/openstack/networking-ovn
* Bugs: http://bugs.launchpad.net/networking-ovn
* Mailing list:
  http://lists.openstack.org/cgi-bin/mailman/listinfo/openstack-dev
* IRC: #openstack-neutron-ovn on Freenode.
* Docs: https://docs.openstack.org/networking-ovn/latest

Team and repository tags
------------------------

.. image:: http://governance.openstack.org/badges/networking-ovn.svg
    :target: http://governance.openstack.org/reference/tags/index.html
